package com.june.entitytodbdoc.entity.mongo.article;

import com.jiankangyouyi.cloud.basedata.api.model.entity.article.ArticleInfo;
import com.jiankangyouyi.cloud.core.base.enums.ValidStatusEnum;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.FieldNameConstants;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.annotation.Version;
import org.springframework.data.mongodb.core.index.CompoundIndex;
import org.springframework.data.mongodb.core.index.CompoundIndexes;
import org.springframework.data.mongodb.core.mapping.Document;

import javax.validation.constraints.NotBlank;

/**
 * @description: 文章库do
 * @author: zyj
 * @email: zhaoyujie@jiankangyouyi.com
 * @date: 2021/10/25 9:53 上午
 */
@EqualsAndHashCode(callSuper = true)
@Data
@FieldNameConstants
@CompoundIndexes(
        value = {
                @CompoundIndex(
                        name = "articleId_1_validStatus_1",
                        def = "{'articleId' : 1, 'validStatus':1}"
                )
        }
)
@Document(collection = "v3.article.library")
public class ArticleDO extends ArticleInfo {
    @Id
    private ObjectId id;

    @Version
    private Long version;

    /**
     * 状态1:有效2:无效 其他：已删除
     */
    @NotBlank(message = "validStatus 不可为空")
    private String validStatus = ValidStatusEnum.VALID.getCode();

    /**
     * 删除人id
     */
    private String delAccountId;



}
